/*
CMDCheckBox v 0.2
By: Donovan Hubbard
http://donovanh.com
http://cybermonkeydev.com

CMDCheckBox(n{name:String}, l{label:String}, up{up-state:*}, sel{select-state:*}, ov{over-state:*}, style{css-class:String})

PUBLIC PROPERTIES
	* input = points to the hidden HTML check box input object.
	* disp = the display content set by the up, over, and select states
	* label = points to the HTML label object

PUBLIC METHODS
	* refresh = refreshes the check box display. typically used after checkbox.input.checked is manually set.
	
NOTES
	* If images are used for the up, over, or selected states, it is a good idea to preload them
		so they transition smoothly with user interactions
	* Tested and works in; FF 21, Opera 12, Chromium 25
	
UPDATES FROM v 0.1
	* Fixed issue where over state would get stuck on mouse out events. The disp element was interfering with mouse event scope.	

DISCLAIMER
	This software comes as is and has not been thoroughly tested. Use at your own risk.
	The autor or contributers are not responsible for possible defects caused by using this.
	Feel free to use this for any means and modify it as you may see fit.

*/
function CMDCheckBox(n, l, up, sel, ov, style)
{
	if(!ov)
		ov = up;
	// main div container
	var cb_wrap = document.createElement("span");
	cb_wrap.style.cursor = "pointer";
	cb_wrap.style.pointerEvents = "all";
	// create hidden input base object
	var new_input = document.createElement("input");
	new_input.type = "checkbox";
	new_input.name = n;
	new_input.id = n;
	new_input.style.display = "inline-block";
	new_input.style.position = "absolute";
	new_input.style.top = "0px";
	new_input.style.left= "0px";
	new_input.style.visibility = "hidden";
	// create label for the input
	var cb_label = document.createElement("label");
	cb_label.style.top = "0px";
	cb_label.style.left = "0px";
	cb_label.style.cursor = "pointer";
	cb_label.style.pointerEvents = "none";
	// create display that will override checkbox
	var disp = document.createElement("span");
	disp.style.display = "inline-block";
	disp.style.position = "relative";
	disp.style.top = "0px";
	disp.style.left = "0px";
	disp.style.margin = "auto";
	disp.innerHTML = up;
	disp.style.cursor = "pointer";
	disp.style.pointerEvents = "none";
	// build objects to cb_wrap
	cb_label.appendChild(new_input);
	cb_label.appendChild(disp);
	cb_label.appendChild(document.createTextNode(l));
	cb_wrap.appendChild(cb_label);
	if(style) 
	{ // set default or custom sytle
		cb_wrap.setAttribute("class", style);
	}else
	{ // match a standard check box style
		cb_wrap.style.position = "relative";
		cb_wrap.style.display = "inline-block";
	}
	// set up mouse interactions
	cb_wrap.style.pointerEvents = "all";
	if(ov!=up)
		cb_wrap.onmouseover = function(){ if(!new_input.checked) disp.innerHTML = ov; }
	cb_wrap.onmouseout = function(){ if(!new_input.checked) disp.innerHTML = up; }
	cb_wrap.onclick = function()
	{
		new_input.checked = !new_input.checked;
		this.refresh();
	}
	cb_wrap.refresh = function()
	{
		if(new_input.checked)
			disp.innerHTML = sel;					
		else
			disp.innerHTML = ov;
	}
	cb_wrap.input = new_input;
	cb_wrap.display = disp;
	cb_wrap.label = cb_label;
	return cb_wrap;
}
